@@ -20,7 +20,7 @@ admin.site.register(Action, ActionAdmin)
 
 
 class StreamAdmin(admin.ModelAdmin):
-    list_display = ('user', 'action', 'get_handler')
+    list_display = ('user', 'action', 'get_created', 'get_handler')
     list_filter = ('action__handler',
                    'action__is_global',
                    'action__actor_content_type',
@@ -28,6 +28,11 @@ class StreamAdmin(admin.ModelAdmin):
                    'action__target_content_type')
     search_fields = ('user__username',)
 
+    def get_created(self, obj):
+        return obj.action.created
+    get_created.short_description = 'Created'
+    get_created.admin_order_field = 'action__created'
+
     def get_handler(self, obj):
         return obj.action.handler
     get_handler.short_description = 'Handler'
